==> pycharmPC-252.28539.4-EAP-CANDIDATE.zip: _sha256.py <==
# encoding: utf-8
# module _sha256
# from /opt/teamcity-agent/system/.persistent_cache/pycharm/pythons4utils/python37/lib/python3.7/lib-dynload/_sha256.cpython-37m-darwin.so
# by generator 1.147
# no doc
# no imports

# functions

def sha224(*args, **kwargs): # real signature unknown
    """ Return a new SHA-224 hash object; optionally initialized with a string. """
    pass

def sha256(*args, **kwargs): # real signature unknown
    """ Return a new SHA-256 hash object; optionally initialized with a string. """
    pass

# classes

class SHA224Type(object):
    # no doc
    def copy(self, *args, **kwargs): # real signature unknown
        """ Return a copy of the hash object. """
        pass

    def digest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a bytes object. """
        pass

    def hexdigest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a string of hexadecimal digits. """
        pass

    def update(self, *args, **kwargs): # real signature unknown
        """ Update this hash object's state with the provided string. """
        pass

    def __init__(self, *args, **kwargs): # real signature unknown
        pass

    block_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    digest_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    name = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default



class SHA256Type(object):
    # no doc
    def copy(self, *args, **kwargs): # real signature unknown
        """ Return a copy of the hash object. """
        pass

    def digest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a bytes object. """
        pass

    def hexdigest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a string of hexadecimal digits. """
        pass

    def update(self, *args, **kwargs): # real signature unknown
        """ Update this hash object's state with the provided string. """
        pass

    def __init__(self, *args, **kwargs): # real signature unknown
        pass

    block_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    digest_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    name = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default



# variables with complex values

__loader__ = None # (!) real value is '<_frozen_importlib_external.ExtensionFileLoader object at 0x105585248>'

__spec__ = None # (!) real value is "ModuleSpec(name='_sha256', loader=<_frozen_importlib_external.ExtensionFileLoader object at 0x105585248>, origin='/opt/teamcity-agent/system/.persistent_cache/pycharm/pythons4utils/python37/lib/python3.7/lib-dynload/_sha256.cpython-37m-darwin.so')"

==> pycharmPC-253.28294.295-EAP-CANDIDATE.zip: _sha256.py <==
# encoding: utf-8
# module _sha256
# from /opt/teamcity-agent/system/.persistent_cache/pycharm/pythons4utils/python311/lib/python3.11/lib-dynload/_sha256.cpython-311-darwin.so
# by generator 1.147
# no doc
# no imports

# functions

def sha224(*args, **kwargs): # real signature unknown
    """ Return a new SHA-224 hash object; optionally initialized with a string. """
    pass

def sha256(*args, **kwargs): # real signature unknown
    """ Return a new SHA-256 hash object; optionally initialized with a string. """
    pass

# classes

class SHA224Type(object):
    # no doc
    def copy(self, *args, **kwargs): # real signature unknown
        """ Return a copy of the hash object. """
        pass

    def digest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a bytes object. """
        pass

    def hexdigest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a string of hexadecimal digits. """
        pass

    def update(self, *args, **kwargs): # real signature unknown
        """ Update this hash object's state with the provided string. """
        pass

    def __init__(self, *args, **kwargs): # real signature unknown
        pass

    block_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    digest_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    name = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default



class SHA256Type(object):
    # no doc
    def copy(self, *args, **kwargs): # real signature unknown
        """ Return a copy of the hash object. """
        pass

    def digest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a bytes object. """
        pass

    def hexdigest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a string of hexadecimal digits. """
        pass

    def update(self, *args, **kwargs): # real signature unknown
        """ Update this hash object's state with the provided string. """
        pass

    def __init__(self, *args, **kwargs): # real signature unknown
        pass

    block_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    digest_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    name = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default



# variables with complex values

__loader__ = None # (!) real value is '<_frozen_importlib_external.ExtensionFileLoader object at 0x10515b850>'

__spec__ = None # (!) real value is "ModuleSpec(name='_sha256', loader=<_frozen_importlib_external.ExtensionFileLoader object at 0x10515b850>, origin='/opt/teamcity-agent/system/.persistent_cache/pycharm/pythons4utils/python311/lib/python3.11/lib-dynload/_sha256.cpython-311-darwin.so')"
